@@ -50,7 +50,7 @@ module.exports = function (url) {
     var entryWs = 'ws://' + host + ':' + port;
     var json = '{ "type":"SsrTestListWs" , "data":"' + entryWs + '" }';
 
-    qrcode.generate(json);
+    qrcode.generate(json, {small: true});
 
     console.log('若出现不符合的情况:',
         '\n绿色字符为App端相对Server端添加的部分',
